package org.maltparser.core.dataformat.writer;

import java.io.BufferedWriter;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.OutputStreamWriter;
import java.io.UnsupportedEncodingException;

import org.maltparser.core.config.ConfigurationException;
import org.maltparser.core.dataformat.DataFormatException;
import org.maltparser.core.exception.MaltChainedException;
import org.maltparser.core.graph.DependencyGraph;
/**
 *  
 *
 * @author Johan Hall
 * @since 1.0
**/
public class TabWriter implements DataWriter {
	private BufferedWriter writer;
	
	public TabWriter() { }
	
	public void initialize(String fileName, String charsetName) throws MaltChainedException {
		try {
			initialize(new OutputStreamWriter(new FileOutputStream(fileName),charsetName));
		} catch (FileNotFoundException e) {
			throw new ConfigurationException("The output file '"+fileName+"' cannot be found.", e);
		} catch (UnsupportedEncodingException e) {
			throw new ConfigurationException("The character encoding set '"+charsetName+"' isn't supported.", e);
		}	
	}
	
	public void initialize(OutputStreamWriter osw) throws MaltChainedException {
		setWriter(new BufferedWriter(osw));
	}
	
	public void writeProlog() throws MaltChainedException { }
	
	public void writeSentence(DependencyGraph dependencyGraph) throws MaltChainedException {
		try {
			writer.write(dependencyGraph.toTab());
		} catch (IOException e) {
			throw new DataFormatException("Cannot write to the output file. ", e);
		}
	}
	
	public void writeEpilog() throws MaltChainedException { }
	
	public BufferedWriter getWriter() {
		return writer;
	}

	public void setWriter(BufferedWriter writer) {
		this.writer = writer;
	}
	
	public void close() throws MaltChainedException {
		try {
			writer.flush();
			writer.close();
		}   catch (IOException e) {
			throw new DataFormatException("Could not close the output file. ", e);
		} 

	}
	
}
