package org.maltparser.core.symbol.trie;

import org.maltparser.core.symbol.SymbolException;

/**

@author Johan Hall
@since 1.0
*/
public class Trie {
	private TrieNode root;
	
	public Trie() {
		root = new TrieNode(' ', null);
	}
	
	public TrieNode addValue(String value, TrieSymbolTable table, int code) throws SymbolException {
		TrieNode node = root;
		for (int i=value.length()-1;i>=0;i--) {
			if (i == 0) {
				node = node.getOrAddChild(true,value.charAt(i),table,node,code);
			} else {
				node = node.getOrAddChild(false,value.charAt(i),table,node,code);
			}
		}
		return node;
	}
	
	public String getValue(TrieNode node, TrieSymbolTable table) {
		StringBuilder sb = new StringBuilder();
		TrieNode tmp = node;
		while (tmp != root && tmp != null) {
			sb.append(tmp.getCharacter());
			tmp = tmp.getParent();
		}
		return sb.toString();
	}
	
	public TrieEntry getEntry(String value, TrieSymbolTable table) {
		TrieNode node = root;
		int i=value.length()-1;
		for (;i>=0 && node != null;i--) {
			node = node.getChild(value.charAt(i));
		}
		if (i < 0 && node != null) {
			return node.getEntry(table);
		} 
		return null;
	}
	
}
